==> file_saver-0.0.2.tar.gz: lib/file_saver_web.dart <==
import 'dart:async';
import 'dart:convert';
// In order to *not* need this ignore, consider extracting the "web" version
// of your plugin as a separate package, instead of inlining it in the same
// package as the core of your plugin.
// ignore: avoid_web_libraries_in_flutter
import 'dart:html';
import 'dart:typed_data';

import 'package:flutter/services.dart';
import 'package:flutter_web_plugins/flutter_web_plugins.dart';

/// A web implementation of the FileSaver plugin.
class FileSaverWeb {
  static void registerWith(Registrar registrar) {
    final MethodChannel channel = MethodChannel(
      'file_saver',
      const StandardMethodCodec(),
      registrar,
    );

    final pluginInstance = FileSaverWeb();
    channel.setMethodCallHandler(pluginInstance.handleMethodCall);
  }

  Future<dynamic> handleMethodCall(MethodCall call) async {
    switch (call.method) {
      case 'saveFile':
        String args = call.arguments;
        Map<String, dynamic> data = json.decode(args);
        Uint8List uint8list = data['bytes'];
        return downloadFile(
          uint8list,
          data['name'],
          data['type'],
          data['ext'],
        );
      default:
        throw PlatformException(
          code: 'Unimplemented',
          details: 'file_saver for web doesn\'t implement \'${call.method}\'',
        );
    }
  }

  void downloadFile(
      List<int> bytes, String name, String type, String ext) async {
    String url;
    AnchorElement anchor;
    try {
      url = Url.createObjectUrlFromBlob(Blob([bytes], type));
      HtmlDocument htmlDocument = document;
      print(url);
      anchor = htmlDocument.createElement('a') as AnchorElement;
      anchor.href = url;
      anchor.style.display = name;
      anchor.download = name + '.' + ext;
      document.body!.children.add(anchor);
      anchor.click();
      document.body!.children.remove(anchor);
    } catch (e) {
      print(e);
    }
  }
}

==> file_saver-0.0.3.tar.gz: lib/file_saver_web.dart <==
import 'dart:async';
import 'dart:convert';
// In order to *not* need this ignore, consider extracting the "web" version
// of your plugin as a separate package, instead of inlining it in the same
// package as the core of your plugin.
// ignore: avoid_web_libraries_in_flutter
import 'dart:html';
import 'dart:typed_data';

import 'package:flutter/services.dart';
import 'package:flutter_web_plugins/flutter_web_plugins.dart';

/// A web implementation of the FileSaver plugin.
class FileSaverWeb {
  static void registerWith(Registrar registrar) {
    final MethodChannel channel = MethodChannel(
      'file_saver',
      const StandardMethodCodec(),
      registrar,
    );

    final pluginInstance = FileSaverWeb();
    channel.setMethodCallHandler(pluginInstance.handleMethodCall);
  }

  Future<dynamic> handleMethodCall(MethodCall call) async {
    switch (call.method) {
      case 'saveFile':
        String args = call.arguments;
        Map<String, dynamic> data = json.decode(args);
        List<dynamic> bytes = data['bytes'];
        Uint8List uint8list = Uint8List.fromList(List<int>.from(bytes));
        return downloadFile(
          uint8list,
          data['name'],
          data['type'],
          data['ext'],
        );
      default:
        throw PlatformException(
          code: 'Unimplemented',
          details: 'file_saver for web doesn\'t implement \'${call.method}\'',
        );
    }
  }

  void downloadFile(
      List<int> bytes, String name, String type, String ext) async {
    String url;
    AnchorElement anchor;
    try {
      url = Url.createObjectUrlFromBlob(Blob([bytes], type));
      HtmlDocument htmlDocument = document;
      print(url);
      anchor = htmlDocument.createElement('a') as AnchorElement;
      anchor.href = url;
      anchor.style.display = name;
      anchor.download = name + '.' + ext;
      document.body!.children.add(anchor);
      anchor.click();
      document.body!.children.remove(anchor);
    } catch (e) {
      print(e);
    }
  }
}
